sagemath_macaulay2_jupyterkernel: Jupyter kernel for Macaulay2
==============================================================

Description
-----------

Jupyter kernel for Macaulay2 (passagemath fork)

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/passagemath-macaulay2-jupyterkernel/
